# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/core/v1/record.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/core/v1/record.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61gntcy/dir/core/v1/record.proto\x12\x12\x61gntcy.dir.core.v1\x1a\x1cgoogle/protobuf/struct.proto\"\x1d\n\tRecordRef\x12\x10\n\x03\x63id\x18\x01 \x01(\tR\x03\x63id\"\xf7\x01\n\nRecordMeta\x12\x10\n\x03\x63id\x18\x01 \x01(\tR\x03\x63id\x12Q\n\x0b\x61nnotations\x18\x02 \x03(\x0b\x32/.agntcy.dir.core.v1.RecordMeta.AnnotationsEntryR\x0b\x61nnotations\x12%\n\x0eschema_version\x18\x03 \x01(\tR\rschemaVersion\x12\x1d\n\ncreated_at\x18\x04 \x01(\tR\tcreatedAt\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"5\n\x06Record\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\"\xc5\x02\n\x0eRecordReferrer\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12<\n\nrecord_ref\x18\x02 \x01(\x0b\x32\x1d.agntcy.dir.core.v1.RecordRefR\trecordRef\x12U\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32\x33.agntcy.dir.core.v1.RecordReferrer.AnnotationsEntryR\x0b\x61nnotations\x12\x1d\n\ncreated_at\x18\x04 \x01(\tR\tcreatedAt\x12+\n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xb3\x01\n\x16\x63om.agntcy.dir.core.v1B\x0bRecordProtoP\x01Z!github.com/agntcy/dir/api/core/v1\xa2\x02\x03\x41\x44\x43\xaa\x02\x12\x41gntcy.Dir.Core.V1\xca\x02\x12\x41gntcy\\Dir\\Core\\V1\xe2\x02\x1e\x41gntcy\\Dir\\Core\\V1\\GPBMetadata\xea\x02\x15\x41gntcy::Dir::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.core.v1.record_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.agntcy.dir.core.v1B\013RecordProtoP\001Z!github.com/agntcy/dir/api/core/v1\242\002\003ADC\252\002\022Agntcy.Dir.Core.V1\312\002\022Agntcy\\Dir\\Core\\V1\342\002\036Agntcy\\Dir\\Core\\V1\\GPBMetadata\352\002\025Agntcy::Dir::Core::V1'
  _globals['_RECORDMETA_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_RECORDMETA_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_RECORDREFERRER_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_RECORDREFERRER_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_RECORDREF']._serialized_start=85
  _globals['_RECORDREF']._serialized_end=114
  _globals['_RECORDMETA']._serialized_start=117
  _globals['_RECORDMETA']._serialized_end=364
  _globals['_RECORDMETA_ANNOTATIONSENTRY']._serialized_start=302
  _globals['_RECORDMETA_ANNOTATIONSENTRY']._serialized_end=364
  _globals['_RECORD']._serialized_start=366
  _globals['_RECORD']._serialized_end=419
  _globals['_RECORDREFERRER']._serialized_start=422
  _globals['_RECORDREFERRER']._serialized_end=747
  _globals['_RECORDREFERRER_ANNOTATIONSENTRY']._serialized_start=302
  _globals['_RECORDREFERRER_ANNOTATIONSENTRY']._serialized_end=364
# @@protoc_insertion_point(module_scope)
