# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/sign/v1/sign_service.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/sign/v1/sign_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agntcy.dir.core.v1 import record_pb2 as agntcy_dot_dir_dot_core_dot_v1_dot_record__pb2
from agntcy.dir.sign.v1 import signature_pb2 as agntcy_dot_dir_dot_sign_dot_v1_dot_signature__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%agntcy/dir/sign/v1/sign_service.proto\x12\x12\x61gntcy.dir.sign.v1\x1a\x1f\x61gntcy/dir/core/v1/record.proto\x1a\"agntcy/dir/sign/v1/signature.proto\"\x90\x01\n\x0bSignRequest\x12<\n\nrecord_ref\x18\x01 \x01(\x0b\x32\x1d.agntcy.dir.core.v1.RecordRefR\trecordRef\x12\x43\n\x08provider\x18\x02 \x01(\x0b\x32\'.agntcy.dir.sign.v1.SignRequestProviderR\x08provider\"\x8d\x01\n\x13SignRequestProvider\x12\x36\n\x04oidc\x18\x01 \x01(\x0b\x32 .agntcy.dir.sign.v1.SignWithOIDCH\x00R\x04oidc\x12\x33\n\x03key\x18\x02 \x01(\x0b\x32\x1f.agntcy.dir.sign.v1.SignWithKeyH\x00R\x03keyB\t\n\x07request\"\xe1\x02\n\x0cSignWithOIDC\x12\x19\n\x08id_token\x18\x01 \x01(\tR\x07idToken\x12\x43\n\x07options\x18\x02 \x01(\x0b\x32).agntcy.dir.sign.v1.SignWithOIDC.SignOptsR\x07options\x1a\xf0\x01\n\x08SignOpts\x12\"\n\nfulcio_url\x18\x01 \x01(\tH\x00R\tfulcioUrl\x88\x01\x01\x12 \n\trekor_url\x18\x02 \x01(\tH\x01R\x08rekorUrl\x88\x01\x01\x12(\n\rtimestamp_url\x18\x03 \x01(\tH\x02R\x0ctimestampUrl\x88\x01\x01\x12/\n\x11oidc_provider_url\x18\x04 \x01(\tH\x03R\x0foidcProviderUrl\x88\x01\x01\x42\r\n\x0b_fulcio_urlB\x0c\n\n_rekor_urlB\x10\n\x0e_timestamp_urlB\x14\n\x12_oidc_provider_url\"\\\n\x0bSignWithKey\x12\x1f\n\x0bprivate_key\x18\x01 \x01(\x0cR\nprivateKey\x12\x1f\n\x08password\x18\x02 \x01(\x0cH\x00R\x08password\x88\x01\x01\x42\x0b\n\t_password\"K\n\x0cSignResponse\x12;\n\tsignature\x18\x01 \x01(\x0b\x32\x1d.agntcy.dir.sign.v1.SignatureR\tsignature\"M\n\rVerifyRequest\x12<\n\nrecord_ref\x18\x01 \x01(\x0b\x32\x1d.agntcy.dir.core.v1.RecordRefR\trecordRef\"f\n\x0eVerifyResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12(\n\rerror_message\x18\x02 \x01(\tH\x00R\x0c\x65rrorMessage\x88\x01\x01\x42\x10\n\x0e_error_message2\xa9\x01\n\x0bSignService\x12I\n\x04Sign\x12\x1f.agntcy.dir.sign.v1.SignRequest\x1a .agntcy.dir.sign.v1.SignResponse\x12O\n\x06Verify\x12!.agntcy.dir.sign.v1.VerifyRequest\x1a\".agntcy.dir.sign.v1.VerifyResponseB\xb8\x01\n\x16\x63om.agntcy.dir.sign.v1B\x10SignServiceProtoP\x01Z!github.com/agntcy/dir/api/sign/v1\xa2\x02\x03\x41\x44S\xaa\x02\x12\x41gntcy.Dir.Sign.V1\xca\x02\x12\x41gntcy\\Dir\\Sign\\V1\xe2\x02\x1e\x41gntcy\\Dir\\Sign\\V1\\GPBMetadata\xea\x02\x15\x41gntcy::Dir::Sign::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.sign.v1.sign_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.agntcy.dir.sign.v1B\020SignServiceProtoP\001Z!github.com/agntcy/dir/api/sign/v1\242\002\003ADS\252\002\022Agntcy.Dir.Sign.V1\312\002\022Agntcy\\Dir\\Sign\\V1\342\002\036Agntcy\\Dir\\Sign\\V1\\GPBMetadata\352\002\025Agntcy::Dir::Sign::V1'
  _globals['_SIGNREQUEST']._serialized_start=131
  _globals['_SIGNREQUEST']._serialized_end=275
  _globals['_SIGNREQUESTPROVIDER']._serialized_start=278
  _globals['_SIGNREQUESTPROVIDER']._serialized_end=419
  _globals['_SIGNWITHOIDC']._serialized_start=422
  _globals['_SIGNWITHOIDC']._serialized_end=775
  _globals['_SIGNWITHOIDC_SIGNOPTS']._serialized_start=535
  _globals['_SIGNWITHOIDC_SIGNOPTS']._serialized_end=775
  _globals['_SIGNWITHKEY']._serialized_start=777
  _globals['_SIGNWITHKEY']._serialized_end=869
  _globals['_SIGNRESPONSE']._serialized_start=871
  _globals['_SIGNRESPONSE']._serialized_end=946
  _globals['_VERIFYREQUEST']._serialized_start=948
  _globals['_VERIFYREQUEST']._serialized_end=1025
  _globals['_VERIFYRESPONSE']._serialized_start=1027
  _globals['_VERIFYRESPONSE']._serialized_end=1129
  _globals['_SIGNSERVICE']._serialized_start=1132
  _globals['_SIGNSERVICE']._serialized_end=1301
# @@protoc_insertion_point(module_scope)
